==> zwap_design_system-0.1.11.tar.gz: lib/organism/popups/base/zwapBasePopup.dart <==
/// IMPORTING THIRD PARTY PACKAGES
import 'package:flutter/material.dart';
import 'package:taastrap/taastrap.dart';
import 'package:zwap_utils/zwap_utils.dart';

/// The interface to define any popup widget
abstract class AbstractBasePopup extends StatefulWidget {

  /// The close popup callBack
  final Function() onCloseCallBack;

  AbstractBasePopup({required this.onCloseCallBack});

  /// The save callBack to retrieve to save the data
  void onSaveCallBack();

}

/// The Base popup class to show any widget as a dialog
class BasePopup {

  /// The context to use to build the dialog
  final BuildContext context;

  /// The function to retrieve the child widget to display inside the dialog
  final AbstractBasePopup Function(Function(BuildContext context))
      getWidgetChild;

  BasePopup({required this.context, required this.getWidgetChild});

  /// The function to close the dialog
  void _closePopup(context) {
    Navigator.pop(context);
  }

  /// The function to show the dialog
  void openPopup() {
    showGeneralDialog(
      barrierDismissible: false,
      barrierColor: Colors.black.withOpacity(0.5),
      context: this.context,
      pageBuilder: (context, anim1, anim2) {
        return Align(
          alignment: Alignment.topCenter,
          child: Container(
            padding: EdgeInsets.symmetric(horizontal: getMultipleConditions(500, 485, 0, 0, 0),
                vertical: getMultipleConditions(40, 40, 0, 0, 0)),
            child: this.getWidgetChild(this._closePopup),
          ),
        );
      },
    );
  }
}

==> zwap_design_system-0.1.12.tar.gz: lib/organism/popups/base/zwapBasePopup.dart <==
/// IMPORTING THIRD PARTY PACKAGES
import 'package:flutter/material.dart';
import 'package:taastrap/taastrap.dart';

/// The interface to define any popup widget
abstract class AbstractBasePopup extends StatefulWidget {

  /// The close popup callBack
  final Function() onCloseCallBack;

  AbstractBasePopup({required this.onCloseCallBack});

  /// The save callBack to retrieve to save the data
  void onSaveCallBack(Map<String, dynamic> json);

}

/// The Base popup class to show any widget as a dialog
class BasePopup {

  /// The context to use to build the dialog
  final BuildContext context;

  /// The function to retrieve the child widget to display inside the dialog
  final AbstractBasePopup Function(Function(BuildContext context))
      getWidgetChild;

  BasePopup({required this.context, required this.getWidgetChild});

  /// The function to close the dialog
  void _closePopup(context) {
    Navigator.pop(context);
  }

  /// The function to show the dialog
  void openPopup() {
    showGeneralDialog(
      barrierDismissible: false,
      barrierColor: Colors.black.withOpacity(0.5),
      context: this.context,
      pageBuilder: (context, anim1, anim2) {
        return Align(
          alignment: Alignment.topCenter,
          child: Container(
            padding: EdgeInsets.symmetric(horizontal: getMultipleConditions(500, 485, 0, 0, 0),
                vertical: getMultipleConditions(40, 40, 0, 0, 0)),
            child: this.getWidgetChild(this._closePopup),
          ),
        );
      },
    );
  }
}
